/*
  Tool                              Test_GetLongPath
  Author                            Carlo Hogeveen
  Website                           eCarlo.nl/tse
  Compatibility for test tool       TSE v4.41.35 upwards
  Compatibility for GetLongPath()   TSE v2.6     upwards
  Compatibily                       Windows, Console, Linux,
                                    Linux short names not tested.
  Version                           1.0.1   28 Jan 2023

  This tool implements and tests the included function GetLongPath(),
  which implements the opposite of TSE v4.41.35's GetShortPath() function.

  The tool tests the function by converting the fully qualified name of the
  current file to its short format (if the file has one) with the TSE function
  GetShortPath(), then uses the here implemented function GetLongPath() to
  revert the short format back to its long format, and then displays all three
  formats for comparison.

  Like GetShortPath(), GetLongPath() leaves quotes around the name intact.

  Note: GetLongPath() will not work for NTFS's alternate data stream names.


  HISTORY

  1         27 Jan 2028
    Initial release.

  1.0.1     28 Jan 2023
    Fixed:
      GetLongPath() now returns the input file specification
      if it refers to a file that no longer exists.

*/


string proc GetLongPath(string file_short_in)
  string  file_short [MAXSTRINGLEN] = Trim(file_short_in)
  string  file_long  [MAXSTRINGLEN] = ''
  integer i                         = 1
  integer ok                        = TRUE
  string  old_quote             [1] = ''

  #ifdef LINUX
    string SLASH [1] = '/'
  #else
    string SLASH [1] = '\'
  #endif

  if (file_short[1] in '"', "'")
  and file_short[1] == file_short[Length(file_short)]
    old_quote  = file_short[1]
    file_short = (file_short[2 .. Length(file_short) - 1])
  endif

  #ifdef LINUX
    if file_short[1] == SLASH
      i = 2
    endif
  #else
    if file_short[1:2] == '\\'
      SLASH     = '\'
      file_long = SLASH
      i         = 3
    endif
    if Pos(':', file_short)
      file_long = GetToken(file_short, ':', 1) + ':'
      i = 2
    endif
  #endif

  for i = i to NumTokens(file_short, SLASH)
    file_long = file_long + SLASH + GetToken(file_short, SLASH, i)
    if FindThisFile(file_long)
      file_long = SplitPath(file_long, _DRIVE_|_PATH_) + FFName()
    else
      ok = FALSE
      break
    endif
  endfor

  ok = ok and FileExists(file_long)

  if ok
    if old_quote <> ''
      file_long = old_quote + file_long + old_quote
    endif
  else
    file_long = file_short_in
  endif

  return(file_long)
end GetLongPath


proc Main()
  string fn_long_in   [MAXSTRINGLEN] = CurrFilename()
  string fn_short_out [MAXSTRINGLEN] = ''
  string fn_long_out  [MAXSTRINGLEN] = ''

  fn_short_out = GetShortPath(fn_long_in)
  // EraseDiskFile(fn_long_in)
  fn_long_out  = GetLongPath(fn_short_out)

  Warn('fn_long_in  :'; fn_long_in  , Chr(13),
       'fn_short_out:'; fn_short_out, Chr(13),
       'fn_long_out :'; fn_long_out )

  PurgeMacro(CurrMacroFilename())
end Main

